@@ -64,7 +64,7 @@ public class Utils {
 	// Logger
 	private static final org.slf4j.Logger logger = LoggerFactory.getLogger(Utils.class);
 	private static final String APPLICATION_ID_CATALOGUE_MANAGER = "org.gcube.datacatalogue.ProductCatalogue"; 
-	private static final String NOTIFICATION_MESSAGE = "Dear members,<br>The product <b></em>PRODUCT_TITLE</em></b> has been just published by <b>USER_FULLNAME</b>.<br>You can find it here: PRODUCT_URL <br>";
+	private static final String NOTIFICATION_MESSAGE = "Dear members,<br>The product PRODUCT_TITLE has been just published by USER_FULLNAME.<br>You can find it here: PRODUCT_URL <br>";
 	private static final String SOCIAL_SERVICE_APPLICATION_TOKEN = "2/tokens/generate-application-token/";
 	private static final String SOCIAL_SERVICE_WRITE_APPLICATION_POST = "2/posts/write-post-app/";
 	private static final String MEDIATYPE_JSON = "application/json";
@@ -136,7 +136,11 @@ public class Utils {
 					List<GCubeRole> roles = roleManager.listRolesByUserAndGroup(userid, groupManager.getGroupId(gCubeGroupName));
 
 					// get highest role according liferay
-					RolesCkanGroupOrOrg correspondentRoleToCheck =  getLiferayHighestRoleInOrg(roles);
+					RolesCkanGroupOrOrg correspondentRoleToCheck = getLiferayHighestRoleInOrg(roles);
+
+					// this is a tricky part...  because we actually do not know if it is a member or there is no ckan instance there
+					if(correspondentRoleToCheck.equals(RolesCkanGroupOrOrg.MEMBER))
+						continue;
 
 					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), correspondentRoleToCheck, toReturn, groupManager, ckanPublisherServicesImpl);
 				}
@@ -155,6 +159,10 @@ public class Utils {
 					// get highest role according liferay
 					RolesCkanGroupOrOrg correspondentRoleToCheck =  getLiferayHighestRoleInOrg(roles);
 
+					// this is a tricky part...  because we actually do not know if it is a member or there is no ckan instance there
+					if(correspondentRoleToCheck.equals(RolesCkanGroupOrOrg.MEMBER))
+						continue;
+
 					checkIfRoleIsSetInCkanInstance(username, gCubeGroupName, gCubeGroup.getGroupId(), correspondentRoleToCheck, toReturn, groupManager, ckanPublisherServicesImpl);
 				}
 
@@ -241,9 +249,6 @@ public class Utils {
 
 		logger.debug("Organization name is " + organizationName);
 
-		// if(organizationName.equals(CKanUtilsImpl.PRODUCTION_CKAN_ORGNAME_ROOT))
-		// return CKanUtilsImpl.PRODUCTION_SCOPE_ROOT;
-
 		GroupManager gm = new LiferayGroupManager();
 		List<GCubeGroup> groups = gm.listGroups();
 		for (GCubeGroup gCubeGroup : groups) {
@@ -350,8 +355,6 @@ public class Utils {
 			} catch (Exception e) {
 				logger.error("Error while retrieving metadata beans ", e);
 			}finally{
-
-				// set the scope back
 				if(oldScope != scopeInWhichDiscover)
 					ScopeProvider.instance.set(oldScope);
 			}
